==> apache-camel-4.10.7-src.zip: apache-camel-4.10.7/dsl/camel-endpointdsl/src/test/java/org/apache/camel/builder/endpoint/SedaToDSimpleExpressionTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.builder.endpoint;

import org.apache.camel.EndpointInject;
import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.component.mock.MockEndpoint;
import org.junit.jupiter.api.Test;

public class SedaToDSimpleExpressionTest extends BaseEndpointDslTest {

    @EndpointInject(value = "mock:result")
    private MockEndpoint result;

    @Override
    protected RouteBuilder createRouteBuilder() throws Exception {
        return new EndpointRouteBuilder() {
            @Override
            public void configure() throws Exception {
                from(direct("start")).toD(seda("${exchangeProperty.whereTo}").blockWhenFull(true));

                from("seda:cheese").to("mock:result");
            }
        };
    }

    @Test
    public void test() throws Exception {
        MockEndpoint resultEndpoint = getMockEndpoint("mock:result");
        resultEndpoint.expectedMessageCount(1);

        template.sendBodyAndProperty("direct:start", "Hello World", "whereTo", "cheese");

        MockEndpoint.assertIsSatisfied(context);
    }
}

==> apache-camel-4.16.0-src.zip: apache-camel-4.16.0/dsl/camel-endpointdsl/src/test/java/org/apache/camel/builder/endpoint/SedaToDSimpleExpressionTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.builder.endpoint;

import org.apache.camel.EndpointInject;
import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.component.mock.MockEndpoint;
import org.junit.jupiter.api.Test;

public class SedaToDSimpleExpressionTest extends BaseEndpointDslTest {

    @EndpointInject(value = "mock:result")
    private MockEndpoint result;

    @Override
    protected RouteBuilder createRouteBuilder() throws Exception {
        return new EndpointRouteBuilder() {
            @Override
            public void configure() throws Exception {
                from(direct("start")).toD(seda("${exchangeProperty.whereTo}").advanced().blockWhenFull(true));

                from("seda:cheese").to("mock:result");
            }
        };
    }

    @Test
    public void test() throws Exception {
        MockEndpoint resultEndpoint = getMockEndpoint("mock:result");
        resultEndpoint.expectedMessageCount(1);

        template.sendBodyAndProperty("direct:start", "Hello World", "whereTo", "cheese");

        MockEndpoint.assertIsSatisfied(context);
    }
}
